==> overview_builder-2.0.2.tar.gz: overview_builder/src/Controller/AjaxController.php <==
<?php

namespace Drupal\overview_builder\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Render\RendererInterface;
use Drupal\overview_builder\OverviewBuilderManager;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

/**
 * Class AjaxController.
 *
 * @package Drupal\overview_builder\Controller
 */
class AjaxController extends ControllerBase {

  /**
   * The overview builder manager.
   *
   * @var \Drupal\overview_builder\OverviewBuilderManager
   */
  protected $overviewBuilderManager;

  /**
   * The renderer service.
   *
   * @var \Drupal\Core\Render\RendererInterface
   */
  protected $renderer;

  /**
   * AjaxController constructor.
   *
   * @param \Drupal\overview_builder\OverviewBuilderManager $overviewBuilderManager
   *   The overview builder manager.
   * @param \Drupal\Core\Render\RendererInterface $renderer
   *   The renderer service.
   */
  public function __construct(OverviewBuilderManager $overviewBuilderManager, RendererInterface $renderer) {
    $this->overviewBuilderManager = $overviewBuilderManager;
    $this->renderer = $renderer;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('plugin.manager.overview_builder'),
      $container->get('renderer')
    );
  }

  /**
   * Callback for /ajax/overview-builder/{plugin_id}.
   *
   * Builds the overview that can be used as ajax callback.
   *
   * @param \Drupal\overview_builder\Controller\string $plugin_id
   *   The plugin ID of the overview that should be build.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   *   An HTML string representing the overview.
   *
   * @throws \Drupal\Component\Plugin\Exception\PluginException
   */
  public function overview(string $plugin_id): Response {
    if (!$this->overviewBuilderManager->hasDefinition($plugin_id)) {
      throw new NotFoundHttpException();
    }

    $plugin_definition = $this->overviewBuilderManager->getDefinition($plugin_id);

    if (empty($plugin_definition['ajax']) || $plugin_definition['ajax'] === FALSE) {
      throw new NotFoundHttpException();
    }

    /** @var \Drupal\overview_builder\OverviewBuilderInterface $plugin */
    $plugin = $this->overviewBuilderManager->createInstance($plugin_id);
    $build = $plugin->build();
    return new Response($this->renderer->renderRoot($build));
  }

}

==> overview_builder-2.0.4.tar.gz: overview_builder/src/Controller/AjaxController.php <==
<?php

namespace Drupal\overview_builder\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Render\RendererInterface;
use Drupal\overview_builder\OverviewBuilderManager;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

/**
 * Controller used to rebuild overview that have ajax enabled.
 *
 * @package Drupal\overview_builder\Controller
 */
class AjaxController extends ControllerBase {

  /**
   * The overview builder manager.
   *
   * @var \Drupal\overview_builder\OverviewBuilderManager
   */
  protected $overviewBuilderManager;

  /**
   * The renderer service.
   *
   * @var \Drupal\Core\Render\RendererInterface
   */
  protected $renderer;

  /**
   * AjaxController constructor.
   *
   * @param \Drupal\overview_builder\OverviewBuilderManager $overviewBuilderManager
   *   The overview builder manager.
   * @param \Drupal\Core\Render\RendererInterface $renderer
   *   The renderer service.
   */
  public function __construct(OverviewBuilderManager $overviewBuilderManager, RendererInterface $renderer) {
    $this->overviewBuilderManager = $overviewBuilderManager;
    $this->renderer = $renderer;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('plugin.manager.overview_builder'),
      $container->get('renderer')
    );
  }

  /**
   * Callback for /ajax/overview-builder/{plugin_id}.
   *
   * Builds the overview that can be used as ajax callback.
   *
   * @param string $plugin_id
   *   The plugin ID of the overview that should be build.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   *   An HTML string representing the overview.
   *
   * @throws \Drupal\Component\Plugin\Exception\PluginException
   */
  public function overview(string $plugin_id): Response {
    if (!$this->overviewBuilderManager->hasDefinition($plugin_id)) {
      throw new NotFoundHttpException();
    }

    $plugin_definition = $this->overviewBuilderManager->getDefinition($plugin_id);

    if (empty($plugin_definition['ajax']) || $plugin_definition['ajax'] === FALSE) {
      throw new NotFoundHttpException();
    }

    /** @var \Drupal\overview_builder\OverviewBuilderInterface $plugin */
    $plugin = $this->overviewBuilderManager->createInstance($plugin_id);
    $build = $plugin->build();
    return new Response($this->renderer->renderRoot($build));
  }

}
